import { Component, OnInit } from '@angular/core';
import { AuthorisationService } from '../authorisation.service';
import { Router, NavigationStart } from '@angular/router';
import { timer } from 'rxjs/observable/timer';




@Component({
  selector: 'app-keygen',
  templateUrl: './keygen.component.html',
  styleUrls: ['./keygen.component.css']
})
export class KeygenComponent implements OnInit {

  constructor(private router: Router, private authService: AuthorisationService) { }

  ngOnInit() {
    // The sequence is tricky here:
    // 1) the auth service loads, examines the fragment and stores the OAuth2 Token required to generate certificates
    // 2) The KeyGen component becomes visible providing a Spinner
    // 3) The timer(0) executes once the component is visiable causing the authService to move onto the next phase
    // 4) The authservice generates ssh keys in javascript (slow) and gets them signed (also slow)
    // 5) The authservice indicates its done by setting readtToNavigate => true
    // 6) the router navigates to the main page (removing the spinner etc)
    // ready to navigate will be set once the keys are generated
    this.authService.readyToNavigate.subscribe(readyToNavigate => this.navigate(readyToNavigate));
    // use of a timer(0) means this will be executed AFTER the component is visiable (hopefully)
    timer(0).subscribe( () => this.genKeys() );
  }

  genKeys() {
    this.authService.getCert(this.authService.token)
  }

  activateToken(token) {
    console.log('activate token called');
  }

  navigate(readyToNavigate: [Boolean,string]) {
    if (readyToNavigate[0]) {
      this.router.navigate([readyToNavigate[1]]);
    }
  }

}
